@@ -82,7 +82,7 @@ module APRS4R
       logger.info( "receiveAPRSMessage( name, message)")
       
       if message.nil?
-        logger.warn( "message: nil\n")
+        logger.warn( "message: NIL")
         return
       end
       
@@ -92,7 +92,7 @@ module APRS4R
         return
       end
       
-      logger.warn( "gating from #{name} to #{@outDevice}, message: #{message}")
+      logger.log( "gating from #{name} to #{@outDevice}, message: #{message}")
       SocketManager.sendAPRSMessage( @outDevice, message)
       
       return
