@@ -96,7 +96,7 @@ module APRS4R
       
       begin 
         
-        host = @hosts.first
+        host = @hosts[rand( @hosts.length)]
         
         logger.debug( "connecting to #{host}:#{@port}")
         @socket = TCPSocket.new( host, @port)
@@ -116,10 +116,8 @@ module APRS4R
         
         # wait 5 seconds before next try
         sleep 5
-        
-        # rotate aprs server list 
-        host = @hosts.delete_at( 0)
-        @hosts << host
+
+        host = @hosts[rand( @hosts.length)]
         
         retry
       end
@@ -295,7 +293,7 @@ module APRS4R
       end
       
       if message.source.nil? || message.destination.nil? 
-        logger.warn( "NIL\n")
+        logger.warn( "message: NIL")
         return nil
       end
 
