@@ -17,24 +17,29 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
-require 'Logger'
+require 'aprs4r/APRS4RBase'
+require 'aprs4r/APRS4RLogger'
 
 require 'aprs4r/PluginConfiguration'
 
 
-class Plugin
+module APRS4R
 
-  @@logger = Logger.get_logger( "Plugin")
+  class Plugin < APRS4RBase
+
+    @logger = APRS4RLogger.get_logger( "Plugin")
 
 
-  def initialize( configuration)
-    @@logger.info( "initialize( configuration)")
+    def initialize( configuration)
+      logger.info( "initialize( configuration)")
 
-    @name = configuration.name
-    @type = configuration.type
-    @enable = configuration.enable
+      @name = configuration.name
+      @type = configuration.type
+      @enable = configuration.enable
+
+      return
+    end
 
-    return
   end
 
 end
