@@ -29,6 +29,8 @@ module APRS4R
 
     @logger = APRS4RLogger.get_logger( "SocketRecvThread");
 
+    @@QUEUE_MAX_LENGTH = 10
+
 
     def initialize( socket)
       logger.info( "initialize( socket)")
@@ -65,9 +67,17 @@ module APRS4R
         message = @socket.readAPRSMessage
 
         if message 
-          logger.warn( "message recv on #{@name}: #{message}")
+          logger.log( "message recv on #{@name}: #{message}")
           # queue message in recv queue
           @queue.push( message)
+
+          # remove first queue element if queue is full
+          if @queue.length > @@QUEUE_MAX_LENGTH
+            begin 
+              @queue.pop( true)
+            rescue Exception 
+            end
+          end
         end
 
       end
