@@ -154,66 +154,52 @@ module APRS4R
     end
 
 
-    def wind_avg_speed
+    def wind_avg
       speed = 0.0
 
       if has_wind? && payload.length >= 6
         speed = low_nibble( payload[5]) * 10.0 + high_nibble( payload[4]) + low_nibble( payload[4]) / 10.0
 
-        speed *= 3.6 / 1.852
       end
       
       return speed
     end
 
 
-    def wind_gust_speed
+    def wind_gust
       speed = 0.0
 
       if has_wind? && payload.length >= 4
         speed = high_nibble( payload[3]) * 10.0 + low_nibble( payload[3]) + high_nibble( payload[2]) / 10.0
         
-        speed *= 3.6 / 1.852
       end
 
       return speed
     end
 
 
-    def rain_current
+    def rain_1h
       rain = 0.0
 
       if has_rain? && payload.length >= 3
         rain = low_nibble( payload[2]) * 100.0 + high_nibble( payload[1]) * 10.0 + low_nibble( payload[1])
 
-        # convert to cm/hr
-        rain /= 10.0
-
-        # convert to inch/hour
-        rain /= 2.54
-        
-        # convert to hundredths of inch
-        rain *= 100.0
+        # convert to m/hr
+        rain /= 100.0
       end
 
       return rain
     end
 
 
-    def rain_total
+    def rain_24h
       rain = 0.0
 
       if has_rain? && payload.length >= 5
         rain = high_nibble( payload[4]) * 1000.0 + low_nibble( payload[4]) * 100.0 + high_nibble( payload[3]) * 10.0 + low_nibble( payload[3]) + high_nibble( payload[2]) / 10.0
 
-        # convert to cm/hr
-        rain /= 10.0
-
-        # convert to inch/hour
-        rain /= 2.54
-        
-        # convert to hundredths of inch
-        rain *= 100.0
+        # convert to m/hr
+        rain /= 100.0
       end
 
       return rain
@@ -226,14 +212,8 @@ module APRS4R
       if has_rain? && payload.length >= 7
         rain = high_nibble( payload[6]) * 1000.0 + low_nibble( payload[6]) * 100.0 + high_nibble( payload[5]) * 10.0 + low_nibble( payload[5])
 
-        # convert to cm/hr
-        rain /= 10.0
-
-        # convert to inch/hour
-        rain /= 2.54
-        
-        # convert to hundredths of inch
-        rain *= 100.0
+        # convert to m/hr
+        rain /= 100.0
       end
 
       return rain
@@ -249,8 +229,6 @@ module APRS4R
         if payload[2].to_i & 0x80
           temperature *= -1.0
         end
-
-        temperature = temperature * 9.0 / 5.0 + 32
       end
 
       return temperature
@@ -273,8 +251,6 @@ module APRS4R
       
       if has_baro? && payload.length >= 5
         dewpoint = high_nibble( payload[4]) * 10.0 + low_nibble( payload[4])
-
-        dewpoint = dewpoint * 9.0 / 5.0 + 32
       end
       
       return dewpoint
