@@ -19,6 +19,7 @@
 
 require 'serialport'
 require 'thread'
+require 'io/nonblock'
 
 require 'aprs4r/APRS4RLogger'
 
@@ -53,6 +54,16 @@ module APRS4R
     end
 
 
+    def start
+      logger.info( "start")
+
+      Thread.new { 
+        runWMRThread
+      }
+
+      return
+    end
+
 
     def runWMRThread
       logger.info( "runWMRThread")
