@@ -118,6 +118,10 @@ module APRS4R
         return
       end
 
+      if !message.has_position? || !message.has_symbol?
+        return 
+      end
+
       @mutex.synchronize do
         
         source = message.source.to_s
@@ -319,7 +323,7 @@ module APRS4R
 
     # escape html symbols (&/><, copied from cgi class)
     def escapeHTML( value) 
-      return value.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')
+      return value.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;') if value
     end
 
   end
